pysarpro 0.1 release notes
===============================

After a brief (!) absence, we're back with a new and shiny version of
pysarpro, the SAR processing toolbox for SciPy.

Contributors for this release
-----------------------------
Islam Mansour